diff --git a/CHANGELOG.rst b/CHANGELOG.rst
index 25d7fa9c369646942a5fd08bda02b304364bcc4b..4ce1290b666c9344f3a999e33653577c3b6a545f 100644
--- a/CHANGELOG.rst
+++ b/CHANGELOG.rst
@@ -5,6 +5,8 @@ These are notable changes in edx-platform.  This is a rolling list of changes,
 in roughly chronological order, most recent first.  Add your entries at or near
 the top.  Include a label indicating the component affected.
 
+Blades: Course teams can turn off Chinese Caching from Studio. BLD-1207
+
 LMS: Instructors can request and see content of previous bulk emails sent in the instructor dashboard.
 
 Studio: New course outline and unit/container pages with revised publishing model. STUD-1790 (part 1)
diff --git a/cms/djangoapps/models/settings/course_metadata.py b/cms/djangoapps/models/settings/course_metadata.py
index 07a1d6b1169ecbad23dc8a8e3b348a84bd5f685a..f716f717bc03598627f249b848e14888dc9e63cc 100644
--- a/cms/djangoapps/models/settings/course_metadata.py
+++ b/cms/djangoapps/models/settings/course_metadata.py
@@ -24,10 +24,8 @@ class CourseMetadata(object):
                      'graded',
                      'hide_from_toc',
                      'pdf_textbooks',
-                     'user_partitions',
                      'name',  # from xblock
                      'tags',  # from xblock
-                     'video_speed_optimizations',
                      'visible_to_staff_only'
     ]
 
diff --git a/common/lib/xmodule/xmodule/modulestore/inheritance.py b/common/lib/xmodule/xmodule/modulestore/inheritance.py
index 4316655a7d4f339259af3a47e70d81fcb10c70da..d305c6641c00fd38a21ea803462d3bf48120ddef 100644
--- a/common/lib/xmodule/xmodule/modulestore/inheritance.py
+++ b/common/lib/xmodule/xmodule/modulestore/inheritance.py
@@ -148,7 +148,8 @@ class InheritanceMixin(XBlockMixin):
         scope=Scope.settings
     )
     video_speed_optimizations = Boolean(
-        help="Enable Video CDN.",
+        display_name=_("Enable video caching system"),
+        help=_("Enter true or false. If true, video caching will be used for HTML5 videos."),
         default=True,
         scope=Scope.settings
     )
diff --git a/common/static/js/vendor/ova/flagging-annotator.js b/common/static/js/vendor/ova/flagging-annotator.js
index 6c2a142a53880fc4ab434afcf30d5d85f9db37f0..66f56b80b3d9ff02939a64a2b193a74caa599aa5 100644
--- a/common/static/js/vendor/ova/flagging-annotator.js
+++ b/common/static/js/vendor/ova/flagging-annotator.js
@@ -76,8 +76,9 @@ Annotator.Plugin.Flagging = (function(_super) {
      */
     Flagging.prototype.updateField = function(field, annotation) {
         
-        // figure out whether annotation is of image or not
-        var user_email = annotation.media === "image" ? 
+        // figure out whether annotation is of type image or if ova is not defined (meaning it
+        // it doesn't have a type yet, but it is still an image).
+        var user_email = (annotation.media === "image" || typeof ova === 'undefined') ? 
                             osda.options.optionsAnnotator.permissions.user.id:
                             ova.options.optionsAnnotator.permissions.user.id;
         
diff --git a/lms/templates/main.html b/lms/templates/main.html
index 1c81419f7fe74d33387e526276795e76bc9ef908..fefc4deec7b75e095537ef286283fe34e6eb0a96 100644
--- a/lms/templates/main.html
+++ b/lms/templates/main.html
@@ -90,6 +90,8 @@
     <script src="${static.url('js/html5shiv.js')}"></script>
   <![endif]-->
 
+  <%include file="widgets/optimizely.html" />
+
   <meta name="path_prefix" content="${EDX_ROOT_URL}">
   <meta name="google-site-verification" content="_mipQ4AtZQDNmbtOkwehQDOgCxUUV2fb_C0b6wbiRHY" />
 
diff --git a/lms/templates/mktg_iframe.html b/lms/templates/mktg_iframe.html
index 8ce5cc1f24ace80219a3584f232aef5e1600094e..c47de902e737b8c2e453e31cc9ccca22225a140c 100644
--- a/lms/templates/mktg_iframe.html
+++ b/lms/templates/mktg_iframe.html
@@ -22,6 +22,8 @@
 
   <%block name="headextra"/>
 
+  <%include file="widgets/optimizely.html" />
+
   <!-- NOTE: if we want segment io on these iframes at some point, put
     include file="widgets/segment-io.html"
   here -->
diff --git a/lms/templates/widgets/optimizely.html b/lms/templates/widgets/optimizely.html
new file mode 100644
index 0000000000000000000000000000000000000000..e8d1b1f2c1c40581d2335e4295f01a9ba03d9e92
--- /dev/null
+++ b/lms/templates/widgets/optimizely.html
@@ -0,0 +1,3 @@
+% if settings.FEATURES.get('OPTIMIZELY_LMS'):
+<script src="//cdn.optimizely.com/js/1706490390.js"></script>
+% endif
diff --git a/lms/envs/common.py b/lms/envs/common.py
index a667fe246ed50a114e2ec4d3a95038d2ea1b2c0c..a339e05b873fd69cfd26f08a1ad3e701d46d74b9 100644
--- a/lms/envs/common.py
+++ b/lms/envs/common.py
@@ -148,7 +148,10 @@ FEATURES = {
     # Staff Debug tool.
     'ENABLE_STUDENT_HISTORY_VIEW': True,
 
-    # segment.io for LMS--need to explicitly turn it on for production.
+    # Optimizely for the LMS--need to explicitly turn on for production.
+    'OPTIMIZELY_LMS': False,
+
+    # Segment.io for LMS--need to explicitly turn on for production.
     'SEGMENT_IO_LMS': False,
 
     # Provide a UI to allow users to submit feedback from the LMS (left-hand help modal)